==> ParaView-v5.1.2.tar.gz: ParaView-v5.1.2/Examples/Catalyst/CxxVTKPipelineExample/FEDriver.cxx <==
#include "FEDataStructures.h"
#include <mpi.h>

#ifdef USE_CATALYST
#include <cstdlib>
#include "FEAdaptor.h"
#include <iostream>
#endif

// Example of a C++ adaptor for a simulation code
// where we use a hard-coded VTK C++ pipeline.
// The simulation code has a fixed topology
// grid. We treat the grid as an unstructured
// grid even though in the example provided it
// would be best described as a vtkImageData.
// Also, the points are stored in an inconsistent
// manner with respect to the velocity vector.
// This is purposefully done to demonstrate
// the different approaches for getting data
// into Catalyst. The hard-coded C++ pipeline
// computes the velocity magnitude from a velocity
// vector and then uses a threshold filter to keep the
// portion of the domain where velocity magnitude
// is within the 10% of the maximum velocity.
// Note that through configuration
// that the driver can be run without linking
// to Catalyst.

int main(int argc, char* argv[])
{
  MPI_Init(&argc, &argv);
  Grid grid;
  unsigned int numPoints[3] = {70, 60, 44};
  double spacing[3] = {1, 1.1, 1.3};
  grid.Initialize(numPoints, spacing);
  Attributes attributes;
  attributes.Initialize(&grid);

#ifdef USE_CATALYST
  bool doCoProcessing = false;
  if(argc == 3)
    {
    doCoProcessing = true;
    // pass in the number of time steps and base file name.
    FEAdaptor::Initialize(atoi(argv[1]), argv[2]);
    }
  else
    {
    std::cerr << "To run with Catalyst you must pass in the output frequency and the base file name.\n";
    }
#endif
  unsigned int numberOfTimeSteps = 100;
  for(unsigned int timeStep=0;timeStep<numberOfTimeSteps;timeStep++)
    {
    // use a time step length of 0.1
    double time = timeStep * 0.1;
    attributes.UpdateFields(time);
#ifdef USE_CATALYST
    if(doCoProcessing)
      {
      FEAdaptor::CoProcess(grid, attributes, time, timeStep,
                           timeStep == numberOfTimeSteps-1);
      }
#endif
    }

#ifdef USE_CATALYST
  if(doCoProcessing)
    {
    FEAdaptor::Finalize();
    }
#endif
  MPI_Finalize();

  return 0;
}

==> ParaView-v5.2.0.tar.gz: ParaView-v5.2.0/Examples/Catalyst/CxxVTKPipelineExample/FEDriver.cxx <==
#include "FEDataStructures.h"
#include <mpi.h>

#ifdef USE_CATALYST
#include "FEAdaptor.h"
#include <cstdlib>
#include <iostream>
#endif

// Example of a C++ adaptor for a simulation code
// where we use a hard-coded VTK C++ pipeline.
// The simulation code has a fixed topology
// grid. We treat the grid as an unstructured
// grid even though in the example provided it
// would be best described as a vtkImageData.
// Also, the points are stored in an inconsistent
// manner with respect to the velocity vector.
// This is purposefully done to demonstrate
// the different approaches for getting data
// into Catalyst. The hard-coded C++ pipeline
// computes the velocity magnitude from a velocity
// vector and then uses a threshold filter to keep the
// portion of the domain where velocity magnitude
// is within the 10% of the maximum velocity.
// Note that through configuration
// that the driver can be run without linking
// to Catalyst.

int main(int argc, char* argv[])
{
  MPI_Init(&argc, &argv);
  Grid grid;
  unsigned int numPoints[3] = { 70, 60, 44 };
  double spacing[3] = { 1, 1.1, 1.3 };
  grid.Initialize(numPoints, spacing);
  Attributes attributes;
  attributes.Initialize(&grid);

#ifdef USE_CATALYST
  bool doCoProcessing = false;
  if (argc == 3)
  {
    doCoProcessing = true;
    // pass in the number of time steps and base file name.
    FEAdaptor::Initialize(atoi(argv[1]), argv[2]);
  }
  else
  {
    std::cerr
      << "To run with Catalyst you must pass in the output frequency and the base file name.\n";
  }
#endif
  unsigned int numberOfTimeSteps = 100;
  for (unsigned int timeStep = 0; timeStep < numberOfTimeSteps; timeStep++)
  {
    // use a time step length of 0.1
    double time = timeStep * 0.1;
    attributes.UpdateFields(time);
#ifdef USE_CATALYST
    if (doCoProcessing)
    {
      FEAdaptor::CoProcess(grid, attributes, time, timeStep, timeStep == numberOfTimeSteps - 1);
    }
#endif
  }

#ifdef USE_CATALYST
  if (doCoProcessing)
  {
    FEAdaptor::Finalize();
  }
#endif
  MPI_Finalize();

  return 0;
}
